@@ -236,8 +236,8 @@ def viperhpdeoptimize(vipertoken,host,port,consumefrom,produceto,companyname,con
         
     value=("viperhpdeoptimize?vipertoken="+vipertoken + "&consumefrom="+consumefrom + "&produceto=" + produceto + "&consumerid="+consumerid +
          "&delay=" + str(delay) + "&enabletls=" + str(enabletls) + "&producerid="+producerid + "&companyname="+companyname +
-         "&partition="+str(partition)+"&offset="+str(offset)+
-         "&hpdehost=" +hpdehost +"&hpdeport="+str(hpdeport))
+         "&partition="+str(partition)+"&offset="+str(offset)+"&ismin="+str(ismin)+"&constraints="+constraints+"&stretchbounds="+str(stretchbounds)+
+         "&hpdehost=" +hpdehost +"&hpdeport="+str(hpdeport)+ "&constrainttype=" +str(constrainttype) +"&epsilon=" +str(epsilon))
     loop = asyncio.get_event_loop()
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid,timeout))
     return val
